% DENSUB DEMO demonstrates usage of the DENSUB package. 

%% MAKE PROBLEM INSTANCE.

% Initialize problem sizes and densities.
M = 100; N = 200;
m = 50; n = 40;
p = 0.25;
q = 0.85;

% Make binary matrix with planted mn-submatrix.
[A,X0,Y0] = plantedsubmatrix(M,N,m,n,p,q);

% Plot A and matrix representations.
figure; imagesc(A);  hold('on'); title('A'); hold('off')% plot matrix.
figure; imagesc(X0);  hold('on'); title('X0'); hold('off')
figure; imagesc(Y0);  hold('on'); title('Y0'); hold('off') % plot matrix rep of submatrix.

%% CALL DENSUB SOLVER.

% Initialize parameters and settings.
tau = 0.35;
maxiter = 500;
verbose = 1;
opt_tol = 1e-4;
gamma = 6/(sqrt(m*n)*(q-p)); % Use optimal choice of gamma from paper.

% Call solver.
[X,Y,Q, iter] = densub(A,m,n, gamma,tau, opt_tol, maxiter, verbose);

% Display iteration/convergence status
if iter < maxiter
    % Converged.
    fprintf('Algorithm converged after %d iterations.\n', iter) 
else
    % Failed to converge.
    fprintf('Algorithm failed to converge within %d iterations.\n', maxiter)
end

% Plot results.
figure; imagesc(X); hold('on'); title('X'); hold('off')
figure; imagesc(Y); hold('on'); title('Y'); hold('off')